==> libreoffice-4.1.3.2.tar.xz: libreoffice-4.1.3.2/starmath/inc/smcommands.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef SM_SNCOMMANDS_HRC
#define SM_SMCOMMANDS_HRC

#define CMD_SID_ADJUST                              ".uno:Adjust"
#define CMD_SID_ALIGN                               ".uno:ChangeAlignment"
#define CMD_SID_DISTANCE                            ".uno:ChangeDistance"
#define CMD_SID_FONT                                ".uno:ChangeFont"
#define CMD_SID_FONTSIZE                            ".uno:ChangeFontSize"
#define CMD_SID_DRAW                                ".uno:Draw"
#define CMD_SID_VIEW100                             ".uno:View100"
#define CMD_SID_VIEW200                             ".uno:View200"
#define CMD_SID_VIEW050                             ".uno:View50"
#define CMD_SID_ZOOMIN                              ".uno:ZoomIn"
#define CMD_SID_ZOOMOUT                             ".uno:ZoomOut"

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_4.3.3.orig.tar.xz: libreoffice-4.3.3.2/starmath/inc/smcommands.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef INCLUDED_STARMATH_INC_SMCOMMANDS_H
#define INCLUDED_STARMATH_INC_SMCOMMANDS_H

#define CMD_SID_ADJUST                              ".uno:Adjust"
#define CMD_SID_ALIGN                               ".uno:ChangeAlignment"
#define CMD_SID_DISTANCE                            ".uno:ChangeDistance"
#define CMD_SID_FONT                                ".uno:ChangeFont"
#define CMD_SID_FONTSIZE                            ".uno:ChangeFontSize"
#define CMD_SID_DRAW                                ".uno:Draw"
#define CMD_SID_VIEW100                             ".uno:View100"
#define CMD_SID_VIEW200                             ".uno:View200"
#define CMD_SID_VIEW050                             ".uno:View50"
#define CMD_SID_ZOOMIN                              ".uno:ZoomIn"
#define CMD_SID_ZOOMOUT                             ".uno:ZoomOut"

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
